/*************************************************************************
*****		Electronic Appendix for MBR537 (in press, 2006)			 *****
*************************************************************************/

* Generic session options - page and line size, page breaks of dashes;
OPTIONS nonumber nodate nocenter pagesize=1000 linesize=140 formdlim='-';											
* Kill default titles on output, turn off tables in log; 
TITLE; ODS TRACE OFF;
* Location for SAS files for these models;
LIBNAME MBR "C:\Folder";
* Importing data file into work library; 
DATA Appendix; SET MBR.Appendix; RUN;

* Location for plots to be exported;
%GLOBAL filesave; %LET filesave=C:\Folder;
* Setting generic plotting options for text, size;
* Save plots to file as bitmap, replace if exist already;
GOPTIONS 
RESET=ALL NOBORDER FTEXT=Triplex FTITLE=Triplex VSIZE=3.5in HSIZE=5.0in
GSFNAME=outgraph DEV=BMP GSFMODE=replace; run;


/***********************************************************************
*****				 Introduction to PROC MIXED 				   *****
***********************************************************************/

/* PROC MIXED syntax commands used below: 

PROC MIXED:
	DATA gives file used for analysis
	METHOD=REML specifies restricted ML or ML (REML is default)
	COVTEST gives significance tests of covariance parameters
	NOCLPRINT suppresses class variable list
	NOITPRINT suppresses iteration history (but use for troubleshooting)
	MAXITER=1000 increases #iterations to 1000
CLASS: defines categorical variables
	Observation identifiers (ID, Day) are categorical
MODEL: defines equation, where [outcome] = [predictors]
	/ SOLUTION asks for parameter estimates
	  DDFM=Satterthwaite specifies Satterthwaite denominator DF
RANDOM: lists random effects (INTERCEPT is not included by default)
	  TYPE=UN specifies unstructured matrix (all variances & covariances)
	/ SUBJECT=ID defines nesting structure for level 2 persons
	/ G, GCORR prints covariance, correlation matrix of random effects
	/ V, VCORR prints combined covariance, correlation matrix from G and R
ODS OUTPUT: saves named table to SAS data set (Table=Datafile)
*/ 

TITLE "Equation 1: Unconditional Random Intercept Model for Positive Mood";											
PROC MIXED DATA=Appendix METHOD=REML COVTEST NOCLPRINT NOITPRINT MAXITER=1000;
	CLASS ID Day;	
  	MODEL pos =  / SOLUTION DDFM=SATTERTHWAITE;	
	RANDOM INTERCEPT / SUBJECT=ID TYPE=UN G V VCORR;			
	ODS OUTPUT CovParms=Cov; RUN;

/*** Begin ICC Calculation ***/

* Transpose saved long covariance parameters to wide;
PROC TRANSPOSE DATA=Cov OUT=ICC; ID CovParm; VAR Estimate; RUN;
* Rename transposed variables;
DATA ICC; SET ICC; 
	IntVar = UN_1_1_;  LABEL IntVar= "Level-2 Random Intercept Variance";
	ResVar = Residual; LABEL ResVar= "Level-1 Residual Variance";
	ICC = IntVar/(IntVar+ResVar); LABEL ICC= "Intraclass Correlation"; RUN;
TITLE "ICC from Empty Model";
PROC PRINT DATA=ICC NOOBS LABEL; VAR IntVar ResVar ICC; RUN;
* Shut off title; TITLE;

/*** END ICC Calculation ***/


/***********************************************************************
*****			Alternative Covariance Structures 				   *****
***********************************************************************/

/* 	The models below use alternative structures of the R matrix 
	(the observed variances and covariances across days) by
	specifying TYPE= on the REPEATED line. 

REPEATED: allows structuring of the residual variance and repeated measures
	Day indicates level-1 nesting (days within persons)
	/ TYPE= specifies covariance structure (see SAS manual for list)
	/ R, RCORR asks for covariance and correlation matrices
	REPEATED is included by default for random effects models
	with TYPE=VC (is identity matrix --> equal variances no covariances)
*/

* Macro variables to generate models for each outcome variable;
* Outcome and name for titles (comment the one not used);
%GLOBAL dv dvtitle;
/*	%LET dv= pos; 	%LET dvtitle= Positive Mood;*/
	%LET dv= neg;	%LET dvtitle= Negative Mood; 
* Predictors to be included besides the intercept;
%GLOBAL predict;    %LET predict= ;

TITLE "&dvtitle. Unstructured Baseline Model";											
PROC MIXED DATA=Appendix METHOD=REML COVTEST NOCLPRINT NOITPRINT MAXITER=1000;
	CLASS ID Day;	
  	MODEL &dv. = &predict. / SOLUTION DDFM=SATTERTHWAITE;			
  	REPEATED Day / TYPE=UN SUBJECT=ID R RCORR; RUN;

TITLE "&dvtitle.: Compound Symmetric Structure";											
PROC MIXED DATA=Appendix METHOD=REML COVTEST NOCLPRINT NOITPRINT MAXITER=1000;
	CLASS ID Day;	
  	MODEL &dv. = &predict. / SOLUTION DDFM=SATTERTHWAITE;			
  	REPEATED Day / TYPE=CS SUBJECT=ID R RCORR; RUN;

TITLE "&dvtitle.: Compound Symmetric Heterogeneous Structure";											
PROC MIXED DATA=Appendix METHOD=REML COVTEST NOCLPRINT NOITPRINT MAXITER=1000;
	CLASS ID Day;	
  	MODEL &dv. = &predict. / SOLUTION DDFM=SATTERTHWAITE;			
  	REPEATED Day / TYPE=CSH SUBJECT=ID R RCORR; RUN;

TITLE "&dvtitle.: Auto-Regressive 1 Structure";											
PROC MIXED DATA=Appendix METHOD=REML COVTEST NOCLPRINT NOITPRINT MAXITER=1000;
	CLASS ID Day;	
  	MODEL &dv. = &predict. / SOLUTION DDFM=SATTERTHWAITE;			
  	REPEATED Day / TYPE=AR(1) SUBJECT=ID R RCORR; RUN;

TITLE "&dvtitle.: Toeplitz Structure";											
PROC MIXED DATA=Appendix METHOD=REML COVTEST NOCLPRINT NOITPRINT MAXITER=1000;
	CLASS ID Day;	
  	MODEL &dv. = &predict. / SOLUTION DDFM=SATTERTHWAITE;		
  	REPEATED Day / TYPE=TOEP SUBJECT=ID R RCORR; RUN;

TITLE "&dvtitle.: Random Intercept + AR1 Structure";											
PROC MIXED DATA=Appendix METHOD=REML COVTEST NOCLPRINT NOITPRINT MAXITER=1000;
	CLASS ID Day;	
  	MODEL &dv. = &predict. / SOLUTION DDFM=SATTERTHWAITE;	
	RANDOM INTERCEPT / TYPE=UN SUBJECT=ID G V VCORR;	
  	REPEATED Day / TYPE=AR(1) SUBJECT=ID R RCORR; RUN;

TITLE "&dvtitle.: Random Intercept + TOEP 1-Lag Structure";											
PROC MIXED DATA=Appendix METHOD=REML COVTEST NOCLPRINT NOITPRINT MAXITER=1000;
	CLASS ID Day;	
  	MODEL &dv. = &predict. / SOLUTION DDFM=SATTERTHWAITE;	
	RANDOM INTERCEPT / TYPE=UN SUBJECT=ID G V VCORR;	
  	REPEATED Day / TYPE=TOEP(2) SUBJECT=ID R RCORR; RUN;

TITLE "&dvtitle.: Random Intercept + TOEP 2-Lag Structure";											
PROC MIXED DATA=Appendix METHOD=REML COVTEST NOCLPRINT NOITPRINT MAXITER=1000;
	CLASS ID Day;	
  	MODEL &dv. = &predict. / SOLUTION DDFM=SATTERTHWAITE;	
	RANDOM INTERCEPT / TYPE=UN SUBJECT=ID G V VCORR;	
  	REPEATED Day / TYPE=TOEP(3) SUBJECT=ID R RCORR; RUN;
* Shut off title; TITLE;
/*** END Alternative Covariance Structures ***/


/***********************************************************************
*****					Examining Effects of Time 				   *****
***********************************************************************/

* Macro variables to generate models for each outcome variable;
* Outcome and name for titles (comment the one not used);
%GLOBAL dv dvtitle;
/*	%LET dv= pos; 	%LET dvtitle= Positive Mood; */
	%LET dv= neg;	%LET dvtitle= Negative Mood; 

* Model for observed means -- useful for examining overall trend;
TITLE "&dvtitle.: Means Model";											
PROC MIXED DATA=Appendix METHOD=REML COVTEST NOCLPRINT NOITPRINT MAXITER=1000;
	CLASS ID Day;	
  	MODEL &dv. = Day / NOINT SOLUTION DDFM=SATTERTHWAITE;	
	RANDOM INTERCEPT / TYPE=UN SUBJECT=ID G; RUN;

* Adding fixed linear effect of time - use Wald test for significance;
TITLE "&dvtitle.: Fixed Effects of Time";											
PROC MIXED DATA=Appendix METHOD=REML COVTEST NOCLPRINT NOITPRINT MAXITER=1000;
	CLASS ID Day;	
  	MODEL &dv. =  time / SOLUTION DDFM=SATTERTHWAITE;	
	RANDOM INTERCEPT / TYPE=UN SUBJECT=ID G; RUN;

* Adding random linear effect of time - use REML deviance test for significance;
TITLE "&dvtitle.: Random Effects of Time";											
PROC MIXED DATA=Appendix METHOD=REML COVTEST NOCLPRINT NOITPRINT MAXITER=1000;
	CLASS ID Day;	
  	MODEL &dv. =  time / SOLUTION DDFM=SATTERTHWAITE;	
	RANDOM INTERCEPT time / TYPE=UN SUBJECT=ID G; RUN;

/*** END Examining Effects of Time ***/


/****************************************************************************
***** 					Test of level-1 heterogeneity 					*****
*****				from Snijders & Bosker 1999 p. 126-7 				*****
****************************************************************************/

* Defining variables used in test program;
%GLOBAL datafile IDlevel2 IDlevel1 pred npred outcome; 
* Name of datafile;			%LET datafile= 	Appendix;
* Level-2 identifier;		%LET IDlevel2= 	ID;
* Level-1 identifier;		%LET IDlevel1= 	Day;
* Level-1 predictors;		%LET pred=		time; 
* Number predictors;		%LET npred= 	1; 
* Outcome variable;			%LET outcome=	pos; 
* Outcome title;			%LET outcometitle= Positive Mood;

/*** Nothing else needs to be changed from here on down ***/

* Opening(emptying) datasets used in program;
DATA OLS_Res OLS OLS_N OLS_Sum OLS_H; RUN;
* Make sure data are sorted by ID first;																					
PROC SORT DATA=&datafile.; BY &IDlevel2. &IDlevel1.; RUN;
* Saving residual variances from level-2 OLS;
PROC REG NOPRINT DATA=&datafile. OUTEST=OLS_Res;		
	* Regression using level 1 predictor model per level-2 unit;
	BY &IDlevel2.; MODEL &outcome.= &pred.; 
	* Save dataset = OLS model residuals with name Resid;	
	OUTPUT OUT=OLS RESIDUAL=Resid; RUN;	
* Examining distribution of residuals;
FILENAME outgraph "&filesave.\Distribution of Residuals for &outcometitle..bmp";
TITLE1 "Distribution of OLS Residuals"; 
TITLE2 "for &outcometitle.";
PROC UNIVARIATE NOPRINT DATA=OLS; VAR Resid; HISTOGRAM Resid; RUN;
* Getting # observations per level-2 unit;
PROC MEANS NOPRINT DATA=OLS; BY &IDlevel2.;
	* Save N of Resid to dataset = OLS_N, name variable Nobs;
	VAR Resid; OUTPUT OUT=OLS_N N(Resid) = Nobs; RUN; 
* Calculating per level-2 unit numerator of lstot from df and residuals;
DATA OLS_Res; 
	MERGE OLS_Res (KEEP= &IDlevel2. _RMSE_) 
		  OLS_N (KEEP= &IDlevel2. Nobs); BY &IDlevel2.;
	LABEL Nobs= "Nobs";
	* Degrees of freedom = n per level2 unit - #predictors - 1;
	df = Nobs - &npred. - 1; 
	* Numerator = df * natural log of variance per level-2 unit;
	num = (df) * (LOG(_RMSE_*_RMSE_)); 
	* Dummy variable used for merging later;
	dummy = 1; RUN;
* Selecting only level-2 units with df GE 10 per S & B's recommendation;
DATA OLS_Res; SET OLS_Res; WHERE df GE 10 AND _RMSE_>0; RUN;
* Sum of df is is denominator, sum of num is numerator; 
* Saved to dataset named OLS_Sum under variable names d2_sum num_sum;
PROC MEANS NOPRINT DATA=OLS_Res; 
	VAR df num; OUTPUT OUT=OLS_Sum SUM(df num)= df_sum num_sum; RUN; 
* Calculating summary statistics;
DATA OLS_Sum; SET OLS_Sum;
	* lstot should be close to natural log of level-1 variance;
	* Calculating lstot = (SUM of numerator) / (SUM df); 
	lstot = num_sum / df_sum;
	* Dummy variable used for merging later;
	dummy = 1;
	* DF for chi-square test;
	* Number level-2 units used;
	dfchi = _FREQ_ - 1;
	* Keep only variables needed;
	KEEP dummy lstot dfchi; RUN;
TITLE "LStot should be close to LN of level-1 variance for &outcometitle.";
PROC PRINT DATA=OLS_Sum; VAR lstot; RUN;
* Merge lstot back into level-2 OLS data;
DATA OLS_Res; MERGE OLS_Res OLS_Sum; BY dummy; 
	* Calculating d per level-2 unit;
	d  = (SQRT(df/2)) * ((LOG(_RMSE_*_RMSE_)) - lstot);
	d2 = d * d; RUN;
* Calculating H as sum of all d2's;
* Saved to dataset named OLS_H under variable name d2_sum;
PROC MEANS NOPRINT DATA=OLS_Res; VAR d2; 
	OUTPUT OUT=OLS_H SUM (d2) = d2_sum; RUN;
* Chi-square test for H;
DATA OLS_H; MERGE OLS_H OLS_Sum;
	* P-value --> calculated H and #groups-1;
	p = 1-PROBCHI(d2_sum,dfchi); 
	LABEL   d2_sum= "H"
			dfchi= 	"DF for obtained H"
			p=		"p-value for obtained H and df"; RUN;
TITLE "P-value for Level-1 Heterogeneity Test for &outcometitle.";
PROC PRINT DATA=OLS_H LABEL; VAR d2_sum dfchi p; RUN; 
TITLE "Level-2 Standardized Deviations for &outcometitle.";
PROC MEANS DATA=OLS_Res; VAR d; RUN;
* Examining distribution of residuals;
FILENAME outgraph "&filesave.\Distribution of d's for &outcometitle..bmp";
TITLE1 "Distribution of d's"; 
TITLE2 "for &outcometitle.";
PROC UNIVARIATE NOPRINT DATA=OLS_Res; VAR d; HISTOGRAM d; RUN;
* Shut off titles; TITLE1; TITLE2;

/*** END test of level-1 heterogeneity ***/


/***********************************************************************
*****			Examining Predictors of Stability 				   *****
***********************************************************************/

/*** Creating variables for analysis ***/ 
DATA Appendix; SET Appendix;
* Centering MMSE at 8 (near distribution midpoint);
	MMSE8 = MMSE - 8; LABEL MMSE8= "MMSE Centered at 8"; 
RUN; /*** END variables for analysis ***/

/*  LOCAL=EXP( ) models level-1 residuals as exponential function of ( ) 
	Note change in SUBJECT= on REPEATED statement -- Day moved */

/*** Positive Mood ***/

TITLE1 "Equation 4: MMSE Model Predicting Positive Mood";
TITLE2 "MMSE as fixed effect only";	
PROC MIXED DATA=Appendix METHOD=REML COVTEST NOCLPRINT NOITPRINT MAXITER=1000;
	CLASS ID Day;	
  	MODEL pos = MMSE8 
		/ SOLUTION DDFM=SATTERTHWAITE;	 
	RANDOM INTERCEPT / TYPE=UN SUBJECT=ID;	
    REPEATED / TYPE=VC SUBJECT=Day(ID); RUN;

TITLE1 "Equation 4: MMSE Model Predicting Positive Mood";
TITLE2 "MMSE as predictor of level-1 residual too";	
PROC MIXED DATA=Appendix METHOD=REML COVTEST NOCLPRINT NOITPRINT MAXITER=1000;
	CLASS ID Day;	
  	MODEL pos = MMSE8 
			/ SOLUTION DDFM=SATTERTHWAITE OUTP=Pos_Res;	* OUTP saves residuals;
	RANDOM INTERCEPT / TYPE=UN SUBJECT=ID;	
    REPEATED / TYPE=VC LOCAL=EXP(MMSE8) SUBJECT=Day(ID); RUN;

* Plot for level-1 residuals (Y) by MMSE (X);
* Shut off titles; TITLE1; TITLE2;
FILENAME outgraph "&filesave.\Positive Mood Residuals by MMSE2.bmp"; 
*TITLE1 JUSTIFY=CENTER HEIGHT=1.5 "Positive Mood Residuals by MMSE"; 
PROC GPLOT DATA=Pos_Res;
	 * Settings for Y-axis;
	 AXIS1 LABEL=(HEIGHT=1.4 ANGLE=90 "Positive Mood Residuals") 
			LENGTH=2.75in ORDER=(-2.5 TO 2.5 BY .5);
	 * Settings for X-axis;
	 AXIS2 LABEL=(HEIGHT=1.4 "Mental Functioning (MMSE)") 
			LENGTH=3.75in ORDER=(0 TO 27 BY 3);
	 * Plot Y by X = person ID, use settings for axes defined above, kill legend;
	 PLOT resid*MMSE / VAXIS=AXIS1 HAXIS=AXIS2 NOLEGEND;
	 * Defining symbols;
	 SYMBOL1 COLOR=Black VALUE=Circle HEIGHT=1 INTERPOL=NONE REPEAT=1000;  
RUN; QUIT;


/*** Negative Mood ***/

TITLE1 "Equation 4: MMSE Model Predicting Negative Mood";
TITLE2 "MMSE as fixed effect only";		
PROC MIXED DATA=Appendix METHOD=REML COVTEST NOCLPRINT NOITPRINT MAXITER=1000;
	CLASS ID Day;	
  	MODEL neg = time MMSE8 MMSE8*MMSE8 
		/ SOLUTION DDFM=SATTERTHWAITE; 
	RANDOM INTERCEPT time  / TYPE=UN SUBJECT=ID;	
    REPEATED / TYPE=VC SUBJECT=Day(ID); RUN;

TITLE1 "Equation 4: MMSE Model Predicting Negative Mood";
TITLE2 "MMSE as predictor of level-1 residual too";	
PROC MIXED DATA=Appendix METHOD=REML COVTEST NOCLPRINT NOITPRINT MAXITER=1000;
	CLASS ID Day;	
  	MODEL neg = time MMSE8 MMSE8*MMSE8 
		/ SOLUTION DDFM=SATTERTHWAITE OUTP=Neg_Res;	 * OUTP saves residuals;	
	RANDOM INTERCEPT time  / TYPE=UN SUBJECT=ID;	
  	REPEATED / TYPE=VC LOCAL=EXP(MMSE8 MMSE8*MMSE8) SUBJECT=Day(ID); RUN;

* Plot for level-1 residuals (Y) by MMSE (X);
* Shut off titles; TITLE1; TITLE2;
FILENAME outgraph "&filesave.\Negative Mood Residuals by MMSE.bmp"; 
*TITLE1 JUSTIFY=CENTER HEIGHT=1.5 "Negative Mood Residuals by MMSE"; 
PROC GPLOT DATA=Neg_Res;
	 * Settings for Y-axis;
	 AXIS1 LABEL=(HEIGHT=1.4 ANGLE=90 "Negative Mood Residuals") 
			LENGTH=2.75in ORDER=(-2.5 TO 2.5 BY .5);
	 * Settings for X-axis;
	 AXIS2 LABEL=(HEIGHT=1.4 "Mental Functioning (MMSE)") 
			LENGTH=3.75in ORDER=(0 TO 27 BY 3);
	 * Plot Y by X = person ID, use settings for axes defined above, kill legend;
	 PLOT resid*MMSE / VAXIS=AXIS1 HAXIS=AXIS2 NOLEGEND;
	 * Defining symbols - draw quadratic regression line;
	 SYMBOL1 COLOR=Black VALUE=Circle HEIGHT=1 INTERPOL=NONE REPEAT=1000;  
RUN; QUIT;


/*** Plotting Predicted Means and Residuals Variances by MMSE ***/

* Data for plots;
DATA Plot; INPUT MMSE; 
	mmse8 = mmse - 8;
* Predicted positive mean from fixed effects;
	posmean = -.07537 + (.01475*mmse8);
* Predicted positive residual variance;
	posres =   .3073 * EXP(-.02782*mmse8);
* Predicted negative mean from fixed effects;
	negmean = -.06049 + (-.04431*mmse8) + (.000481*mmse8*mmse8);
* Predicted negative residual variance;
	negres =   .3000 * EXP( (-.03963*mmse8) + (-.00753*mmse8*mmse8) ) ;
* Stacking data so single Y for each plot;
	y = posmean; dv=1; OUTPUT;
	y = posres;  dv=2; OUTPUT;
	y = negmean; dv=3; OUTPUT;
	y = negres;  dv=4; OUTPUT;
* MMSE values to plot with;
CARDS;
0
3
6
9
12
15
18
21
; RUN;
PROC SORT DATA=Plot; BY dv; run;

* Setting generic plotting options for text, size;
* Save plots to file as bitmap, replace if exist already;
GOPTIONS 
RESET=ALL NOBORDER FTEXT=Triplex FTITLE=Triplex VSIZE=3.5in HSIZE=5.0in
GSFNAME=outgraph DEV=BMP GSFMODE=replace; run;

* Plot for predicted means (Y) by MMSE (X);
* Shut off titles; TITLE1; TITLE2;
FILENAME outgraph "&filesave.\Predicted Means by MMSE.bmp"; 
*TITLE1 JUSTIFY=CENTER HEIGHT=1.5 "Predicted Means by MMSE"; 
PROC GPLOT DATA=Plot; WHERE DV=1 OR DV=3;
	 * Settings for Y-axis;
	 AXIS1 LABEL=(HEIGHT=1.4 ANGLE=90 "Mean Mood") 
			LENGTH=2.50in ORDER=(-1.0 TO 1.0 BY .2);
	 * Settings for X-axis;
	 AXIS2 LABEL=(HEIGHT=1.4 "Mental Functioning (MMSE)") 
			LENGTH=4.00in ORDER=(0 TO 21 BY 3);
	 * Settings for legend;
	 LEGEND1 NOFRAME POSITION=(CENTER TOP) ACROSS=2 LABEL=NONE 
		VALUE=(HEIGHT=1.3 COLOR=Black 
		"Positive Mood"  "Negative Mood") ;
	 * Plot Y by X = person ID, use settings for axes, legend defined above;
	 PLOT Y*MMSE=dv / VAXIS=AXIS1 HAXIS=AXIS2 LEGEND=LEGEND1;
	 * Defining symbol for positive and negative;
	 SYMBOL1 COLOR=Black VALUE=Square HEIGHT=1.3 LINE=1 WIDTH=2;
	 SYMBOL2 COLOR=Black VALUE=Circle HEIGHT=1.3 LINE=3 WIDTH=2;
RUN; QUIT;

* Plot for predicted residual variances (Y) by MMSE (X);
* Shut off titles; TITLE1; TITLE2;
FILENAME outgraph "&filesave.\Predicted Residual Variance by MMSE.bmp"; 
*TITLE1 JUSTIFY=CENTER HEIGHT=1.5 "Predicted Residual Variance by MMSE"; 
PROC GPLOT DATA=Plot; WHERE DV=2 OR DV=4;
	 * Settings for Y-axis;
	 AXIS1 LABEL=(HEIGHT=1.4 ANGLE=90 "Residual Variance") 
			LENGTH=2.50in ORDER=(0.0 TO .5 BY .1);
	 * Settings for X-axis;
	 AXIS2 LABEL=(HEIGHT=1.4 "Mental Functioning (MMSE)") 
			LENGTH=4.00in ORDER=(0 TO 21 BY 3);
	 * Settings for legend;
	 LEGEND1 NOFRAME POSITION=(CENTER TOP) ACROSS=2 LABEL=NONE 
		VALUE=(HEIGHT=1.3 COLOR=Black 
		"Positive Mood"  "Negative Mood") ;
	 * Plot Y by X = person ID, use settings for axes, legend defined above;
	 PLOT Y*MMSE=dv / VAXIS=AXIS1 HAXIS=AXIS2 LEGEND=LEGEND1;
	 * Defining symbol for positive and negative;
	 SYMBOL1 COLOR=Black VALUE=Square HEIGHT=1.3 LINE=1 WIDTH=2;
	 SYMBOL2 COLOR=Black VALUE=Circle HEIGHT=1.3 LINE=3 WIDTH=2;
RUN; QUIT;

/*** END Examining Predictors of Stability ***/


/***********************************************************************
*****			Examining Predictors of Covariation 			   *****
***********************************************************************/

/*** Creating variables for analysis ***/ 
DATA Appendix; SET Appendix;
* Creating predictors for neg mood --> pos mood;
	* Between-Person parameter is created from person mean;
	* Doesn't need to be centered because 0 is within metric already;
	BPneg = PMneg - 0; 
		LABEL BPneg= "Between-Person Negative Mood Centered at 0";
	* Within-Person parameter is difference from person mean; 
	WPneg = neg - PMneg; 
		LABEL WPneg= "Within-Person Deviation Negative Mood"; 
* Creating predictors for pos mood --> ned mood;
	* Between-Person parameter is created from person mean;
	* Doesn't need to be centered because 0 is within metric already;
	BPpos = PMpos - 0; 
		LABEL BPpos= "Between-Person Positive Mood Centered at 0";
	* Within-Person parameter is difference from person mean; 
	WPpos = pos - PMpos; 
		LABEL WPpos= "Within-Person Deviation Positive Mood";	
RUN; /*** END variables for analysis ***/

* Negative mood predicting positive mood;

TITLE1 "Equation 5: MMSE Covariation Model";
TITLE2 "BP and WP Negative Mood Predicting Positive Mood";											
PROC MIXED DATA=Appendix METHOD=REML COVTEST NOCLPRINT NOITPRINT MAXITER=1000;
	CLASS ID Day;	
  	MODEL pos = BPneg WPneg BPneg*WPneg MMSE8 MMSE8*BPneg MMSE8*WPneg 
				/ SOLUTION DDFM=SATTERTHWAITE;	
	RANDOM INTERCEPT / TYPE=UN SUBJECT=ID;		
  	REPEATED / TYPE=VC LOCAL=EXP(MMSE8) SUBJECT=Day(ID); RUN;	

TITLE1 "Equation 5: MMSE Covariation Model";
TITLE2 "Drop non-significant BP*WP interaction";											
PROC MIXED DATA=Appendix METHOD=REML COVTEST NOCLPRINT NOITPRINT MAXITER=1000;
	CLASS ID Day;	
  	MODEL pos = BPneg WPneg MMSE8 MMSE8*BPneg MMSE8*WPneg
				/ SOLUTION DDFM=SATTERTHWAITE;	
	RANDOM INTERCEPT / TYPE=UN SUBJECT=ID;		
  	REPEATED / TYPE=VC LOCAL=EXP(MMSE8) SUBJECT=Day(ID); RUN;	

TITLE1 "Equation 5: MMSE Covariation Model";
TITLE2 "Adding random effect of WP neg mood";											
PROC MIXED DATA=Appendix METHOD=REML COVTEST NOCLPRINT NOITPRINT MAXITER=1000;
	CLASS ID Day;	
  	MODEL pos = BPneg WPneg MMSE8 MMSE8*BPneg MMSE8*WPneg
				/ SOLUTION DDFM=SATTERTHWAITE;	
	RANDOM INTERCEPT WPneg / TYPE=UN SUBJECT=ID;		
  	REPEATED / TYPE=VC LOCAL=EXP(MMSE8) SUBJECT=Day(ID); RUN;	

TITLE1 "Equation 5: MMSE Covariation Model";
TITLE2 "BP and WP Negative Mood Predicting Positive Mood";											
PROC MIXED DATA=Appendix METHOD=REML COVTEST NOCLPRINT NOITPRINT MAXITER=1000;
	CLASS ID Day;	
  	MODEL neg = BPpos WPpos BPpos*WPpos MMSE8 MMSE8*BPpos MMSE8*WPpos 
				/ SOLUTION DDFM=SATTERTHWAITE;	
	RANDOM INTERCEPT / TYPE=UN SUBJECT=ID;		
  	REPEATED / TYPE=VC LOCAL=EXP(MMSE8) SUBJECT=Day(ID); RUN;	

* Positive mood predicting negative mood;

TITLE1 "Equation 5: MMSE Covariation Model";
TITLE2 "BP and WP Positive Mood Predicting Negative Mood";											
PROC MIXED DATA=Appendix METHOD=REML COVTEST NOCLPRINT NOITPRINT MAXITER=1000;
	CLASS ID Day;	
  	MODEL neg = BPpos WPpos BPpos*WPpos MMSE8 MMSE8*BPpos MMSE8*WPpos 
				/ SOLUTION DDFM=SATTERTHWAITE;	
	RANDOM INTERCEPT WPpos / TYPE=UN SUBJECT=ID;		
  	REPEATED / TYPE=VC LOCAL=EXP(MMSE8) SUBJECT=Day(ID); RUN;
	
/*** END Examining Predictors of Covariation ***/





